Crate sifive_fe310_g002

Crate sifive_fe310_g002 

SiFive FE310-G002 Library

Crates.io Page Docs.rs Page License

This library contains bindings for the various peripherals on the SiFive FE310-G002 chip, for easier (and safe) use in Rust.

Note that this library is a work-in-progress, so it may not have the functionality you want. Contributions are welcome.

Re-exports

pub use riscv;

Modules

clint
Bindings for interacting with CLINT (Core-Local INterrupt Controller)
gpio
Bindings for interacting with the GPIO controller
spi
Bindings for interacting with the SPI controllers
uart
Bindings for interacting with the UART controllers